@@ -4,11 +4,10 @@ no strict 'refs';
 
 sub import {
     my ($pkg,$filename,$line) = caller();
-    my $dir = dirname $filename;
-    my $script = -f "$dir/../blib/script/yars" ? "$dir/../blib/script/yars" : "$dir/../bin/yars";
-    my $yars_exe = "$^X $script";
+    my $yars_exe = $^X.' '.dirname($filename).'/../blib/script/yars';
     *{"$pkg".'::sys'} = sub {
         my $cmd = shift;
+        $ENV{PERL5LIB} = join ':', @INC;
         $cmd =~ s/\byars(?= )/$yars_exe/;
         system($cmd)==0 or die "Error running $cmd : $!";
     }
